@@ -66,21 +66,6 @@ typedef struct {
 
 static MateAboutMe *me = NULL;
 
-/*** Utility functions ***/
-static void
-about_me_error (GtkWindow *parent, gchar *str)
-{
-	GtkWidget *dialog;
-
-	dialog = gtk_message_dialog_new (parent,
-				         GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
-				         GTK_BUTTONS_OK, "%s", str);
-
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
-}
-
-/********************/
 static void
 about_me_destroy (void)
 {
@@ -100,44 +85,39 @@ static void
 about_me_load_photo (MateAboutMe *me)
 {
 	gchar         *file;
-        GError        *error = NULL;
+	GError        *error = NULL;
 
 	file = g_build_filename (g_get_home_dir (), ".face", NULL);
-        me->image = gdk_pixbuf_new_from_file(file, &error);
+	me->image = gdk_pixbuf_new_from_file(file, &error);
 
-        if (me->image != NULL) {
+	if (me->image != NULL) {
 		e_image_chooser_set_from_file (E_IMAGE_CHOOSER (me->image_chooser), file);
-                me->have_image = TRUE;
-        } else {
-                me->have_image = FALSE;
-                g_warning ("Could not load %s: %s", file, error->message);
-                g_error_free (error);
-        }
+		me->have_image = TRUE;
+	} else {
+		me->have_image = FALSE;
+		g_warning ("Could not load %s: %s", file, error->message);
+		g_error_free (error);
+	}
 
-        g_free (file);
+	g_free (file);
 }
 
 static void
 about_me_update_photo (MateAboutMe *me)
 {
-	GtkBuilder    *dialog;
 	gchar         *file;
 	GError        *error;
-        gboolean       result;
 
 	guchar 	      *data;
 	gsize 	       length;
 
-	dialog = me->dialog;
-
-
 	if (me->image_changed && me->have_image) {
 		GdkPixbufLoader *loader = gdk_pixbuf_loader_new ();
 		GdkPixbuf *pixbuf = NULL, *scaled = NULL;
 		int height, width;
 		gboolean do_scale = FALSE;
 		float scale = 1.0;
-                float scalex = 1.0, scaley = 1.0;
+		float scalex = 1.0, scaley = 1.0;
 
 		e_image_chooser_get_image_data (E_IMAGE_CHOOSER (me->image_chooser), (char **) &data, &length);
 
@@ -158,12 +138,13 @@ about_me_update_photo (MateAboutMe *me)
 		width = gdk_pixbuf_get_width (pixbuf);
 
 		if (width > MAX_WIDTH) {
-                        scalex = (float)MAX_WIDTH/width;
+			scalex = (float)MAX_WIDTH/width;
 			if (scalex < scale) {
 				scale = scalex;
 			}
 			do_scale = TRUE;
 		}
+
 		if (height > MAX_HEIGHT) {
 			scaley = (float)MAX_HEIGHT/height;
 			if (scaley < scale) {
@@ -189,7 +170,7 @@ about_me_update_photo (MateAboutMe *me)
 		/* FIXME: I would have to read the default used by the mdmgreeter program */
 		error = NULL;
 		file = g_build_filename (g_get_home_dir (), ".face", NULL);
-                if (g_file_set_contents (file, (gchar *)data, length, &error) == TRUE) {
+		if (g_file_set_contents (file, (gchar *)data, length, &error) == TRUE) {
 			g_chmod (file, 0644);
 		} else {
 			g_warning ("Could not create %s: %s", file, error->message);
@@ -197,8 +178,7 @@ about_me_update_photo (MateAboutMe *me)
 		}
 
 		g_free (file);
-                g_object_unref (pixbuf);
-
+		g_object_unref (pixbuf);
 	} else if (me->image_changed && !me->have_image) {
 		/* Update the image in the card */
 		file = g_build_filename (g_get_home_dir (), ".face", NULL);
@@ -263,8 +243,8 @@ about_me_update_preview (GtkFileChooser *chooser,
 			gtk_image_set_from_pixbuf (GTK_IMAGE (image), pixbuf);
 			g_object_unref (pixbuf);
 		} else {
-			gtk_image_set_from_stock (GTK_IMAGE (image),
-						  "gtk-dialog-question",
+			gtk_image_set_from_icon_name (GTK_IMAGE (image),
+						  "dialog-question",
 						  GTK_ICON_SIZE_DIALOG);
 		}
 	}
@@ -362,13 +342,15 @@ about_me_icon_theme_changed (GtkWindow    *window,
 	GtkIconInfo *icon;
 
 	icon = gtk_icon_theme_lookup_icon (me->theme, "stock_person", 80, 0);
-	if (icon == NULL) {
-		g_debug ("Icon not found");
+	if (icon != NULL) {
+		g_free (me->person);
+		me->person = g_strdup (gtk_icon_info_get_filename (icon));
+#if GTK_CHECK_VERSION (3, 8, 0)
+		g_object_unref (icon);
+#else
+		gtk_icon_info_free (icon);
+#endif
 	}
-	g_free (me->person);
-	me->person = g_strdup (gtk_icon_info_get_filename (icon));
-
-	gtk_icon_info_free (icon);
 
 	if (me->have_image)
 		e_image_chooser_set_from_file (E_IMAGE_CHOOSER (me->image_chooser), me->person);
@@ -377,16 +359,12 @@ about_me_icon_theme_changed (GtkWindow    *window,
 static void
 about_me_button_clicked_cb (GtkDialog *dialog, gint response_id, MateAboutMe *me)
 {
-	if (response_id == GTK_RESPONSE_HELP)
-		g_print ("Help goes here");
-	else {
-		if (me->commit_timeout_id) {
-			g_source_remove (me->commit_timeout_id);
-		}
-
-		about_me_destroy ();
-		gtk_main_quit ();
+	if (me->commit_timeout_id) {
+		g_source_remove (me->commit_timeout_id);
 	}
+
+	about_me_destroy ();
+	gtk_main_quit ();
 }
 
 static void
@@ -413,11 +391,10 @@ about_me_setup_dialog (void)
 	GtkWidget    *main_dialog;
 	GtkIconInfo  *icon;
 	GtkBuilder   *dialog;
-	GError 	     *error = NULL;
 	gchar        *str;
 
 	me = g_new0 (MateAboutMe, 1);
-        me->image = NULL;
+	me->image = NULL;
 
 	dialog = gtk_builder_new ();
 	gtk_builder_add_from_file (dialog, MATECC_UI_DIR "/mate-about-me-dialog.ui", NULL);
@@ -447,7 +424,11 @@ about_me_setup_dialog (void)
 	icon = gtk_icon_theme_lookup_icon (me->theme, "stock_person", 80, 0);
 	if (icon != NULL) {
 		me->person = g_strdup (gtk_icon_info_get_filename (icon));
+#if GTK_CHECK_VERSION (3, 8, 0)
+		g_object_unref (icon);
+#else
 		gtk_icon_info_free (icon);
+#endif
 	}
 
 	g_signal_connect_object (me->theme, "changed",
